@@ -48,7 +48,7 @@ void cmdline_write_history()
 
     char* histfile = getenv("HISTORY_FILE");
     if(histfile) 
-        strncpy(path, histfile, PATH_MAX);
+        xstrncpy(path, histfile, PATH_MAX);
     else {
         snprintf(path, PATH_MAX, "%s/history", gHomeDir);
     }
@@ -86,9 +86,6 @@ void cmdline_read_history()
 {
     /// ヒストリを初期化 ///
     int i;
-    for(i=0; i<vector_size(gHistory); i++) {
-        string_delete(vector_item(gHistory, i));
-    }
     vector_clear(gHistory);
 
     /// ヒストリを.mhisotryから読み込む ///
@@ -99,7 +96,7 @@ void cmdline_read_history()
         exit(1);
     }
     char path[PATH_MAX];
-    strncpy(path, env, PATH_MAX);
+    xstrncpy(path, env, PATH_MAX);
 
     if(access(path, R_OK) == 0) {
         string_obj* line = STRING_NEW("");
@@ -131,12 +128,9 @@ void cmdline_read_history()
                 line2[size2] = 0;
 
                 vector_add(gHistory, STRING_NEW(line2));
-                FREE(line2);
                 string_erase(line, 0, size2+1);
             }
         }
-
-        string_delete(line);
     }
 }
 
@@ -155,19 +149,6 @@ void cmdline_init()
 
 void cmdline_final()
 {
-    string_delete(gCmdLine);
-    string_delete(gCmdLineSaved);
-
-    int i;
-    for(i=0; i<vector_size(gHistory); i++) {
-        string_delete(vector_item(gHistory, i));
-    }
-    vector_delete(gHistory);
-
-    for(i=0; i<vector_size(gHCandidate); i++) {
-        string_delete(vector_item(gHCandidate, i));
-    }
-    vector_delete(gHCandidate);
 }
 
 void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
@@ -210,9 +191,6 @@ void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
     }
 
     int i;
-    for(i=0; i<vector_size(gHCandidate); i++) {
-        string_delete(vector_item(gHCandidate, i));
-    }
     vector_clear(gHCandidate);
 
     const int len = vector_size(gHistory);
@@ -253,22 +231,21 @@ void cmdline_convert()
         char* des = MALLOC(des_size + 1);
 #if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
         if(is_all_ascii(src)) {
-            strncpy(des, src, des_size);
+            xstrncpy(des, src, des_size);
         }
         else {
             /// コンバート ///
             if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) < 0) {
-                strncpy(des, src, des_size);
+                xstrncpy(des, src, des_size);
             }
         }
 #else
-        strncpy(des, src, des_size);
+        xstrncpy(des, src, des_size);
 #endif
         string_put(gCmdLine, des);
         if(string_length(gCmdLine) > kCmdLineMax) {
             string_trunc(gCmdLine, kCmdLineMax);
         }
-        FREE(des);
     }
 }
 
@@ -283,7 +260,6 @@ void cmdline_input(int meta, int key)
 
     if(key == 14 || key == KEY_DOWN) {    // CTRL-N
         if(gHistoryCursor == 0) {
-            string_delete(gCmdLine);
             gCmdLine = STRING_NEW(string_c_str(gCmdLineSaved));
             gCmdLineCursor = strlen(string_c_str(gCmdLine));
             gHistoryCursor = -1;
@@ -301,7 +277,6 @@ void cmdline_input(int meta, int key)
             gHistoryCursor = 0;
             gHistoryScrollTop = 0;
 
-            string_delete(gCmdLineSaved);
             gCmdLineSaved = STRING_NEW(string_c_str(gCmdLine));
         }
     }
@@ -632,9 +607,6 @@ void cmdline_input(int meta, int key)
 //    cmdline_convert();
 
     if(gHistoryCursor == -1) {
-        for(i=0; i<vector_size(gHCandidate); i++) {
-            string_delete(vector_item(gHCandidate, i));
-        }
         vector_clear(gHCandidate);
 
         len = vector_size(gHistory);
@@ -665,7 +637,6 @@ void cmdline_input(int meta, int key)
         string_obj* candidate = (string_obj*)vector_item(
                                              gHCandidate, gHistoryCursor);
         if(candidate) {
-            string_delete(gCmdLine);
             gCmdLine = STRING_NEW(string_c_str(candidate));
             gCmdLineCursor = strlen(string_c_str(gCmdLine));
         }
@@ -679,9 +650,6 @@ void cmdline_input(int meta, int key)
 void cmdline_hcandidate_refresh()
 {
     int i;
-    for(i=0; i<vector_size(gHCandidate); i++) {
-        string_delete(vector_item(gHCandidate, i));
-    }
     vector_clear(gHCandidate);
 
     int len = vector_size(gHistory);
@@ -733,7 +701,6 @@ static void cmdline_view_utf8_multi_line()
         
         /// 行の限界まできたら ///
         else if(line >= maxy) {
-            FREE(buf);
             break;
         }
 
@@ -758,8 +725,6 @@ static void cmdline_view_utf8_multi_line()
             line_top = line_end;
             n = 0;
             line++;
-
-            FREE(buf2);
         }
 
         /// 文字列の終端まで達していたら ///
@@ -771,8 +736,6 @@ static void cmdline_view_utf8_multi_line()
 
             mmvprintw(line, 0, "%s", line_top);
 
-            FREE(buf);
-
             break;
         }
 
@@ -780,8 +743,6 @@ static void cmdline_view_utf8_multi_line()
         else {
             n++;
         }
-
-        FREE(buf);
     }
 
     /// カーソル移動 ///
@@ -836,7 +797,6 @@ static void cmdline_view_utf8_2line()
 
                     mmvprintw(maxy-2, 2, "%s", line1);
                     mmvprintw(maxy-1, 0, "%s", pointer);
-                    FREE(line1);
                     break;
                 }
             }
@@ -914,8 +874,6 @@ static void cmdline_view_filer()
         saphire_sweep();
 
         mmvprintw(maxy -2, 0, "%s", string_c_str(str));
-
-        string_delete(str);
     }
 
     /// カーソル下のファイルの情報を描写 ///          
@@ -923,7 +881,7 @@ static void cmdline_view_filer()
     sFile* file = filer_cursor_file(adir());
 
     char permission[12];
-    strncpy(permission, "----------", 12);
+    xstrncpy(permission, "----------", 12);
 
     if(S_ISDIR(file->mLStat.st_mode)) permission[0] = 'd';  // ファイルの種別
     if(S_ISCHR(file->mLStat.st_mode)) permission[0] = 'c';
@@ -980,13 +938,13 @@ static void cmdline_view_filer()
     int width = filer_make_size_str(size_buf, file->mLStat.st_size);
 
     if(S_ISDIR(file->mStat.st_mode)) {
-        strncpy(size_buf, "<DIR>", 256);
+        xstrncpy(size_buf, "<DIR>", 256);
     }
 
     char format[128];
-    strncpy(format, "%", 128);
+    xstrncpy(format, "%", 128);
     snprintf(format + 1, 126, "%d", width);
-    strncat(format, "s", 128);
+    xstrncat(format, "s", 128);
 
     char size_buf2[256];
     snprintf(size_buf2, 256, format, size_buf);
@@ -1063,8 +1021,6 @@ void cmdline_history_view()
         if(gHistoryCursor == i) mattroff();
         line--;
         
-        FREE(tmp);
-
         if(line < 0) {
             break;
         }
